pygeodesy.namedTuples.Bounds4Tuple

Package pygeodesy :: Module namedTuples :: Class Bounds4Tuple |
[frames] | no frames]

# Class Bounds4Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Bounds4Tuple

4-Tuple `(latS, lonW, latN, lonE)` with the bounds' lower-left `(LatS, LowW)` and upper-right `(latN, lonE)` corner lat- and longitudes.

Instance Methods
enclosures(self, S_other, *W_N_E) Get the enclosures of this around an other Bounds4Tuple. |
overlap(self, S_other, *W_N_E) Intersect this with an other Bounds4Tuple. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### enclosures (self, S_other, *W_N_E) |
Get the enclosures of this around an other Bounds4Tuple. Arguments: `S_other` - Bottom `latS` (`scalar`) or an other Bounds4Tuple instance. `W_N_E` - Left `lonW`, top `latN` and right `lonE`, each a (`scalar`) for `scalar S_other`. Returns: A Bounds4Tuple with the margin at each of the 4 sides, positive if this side encloses (is on the outside of) the other, negative if not or zero if abutting.

### overlap (self, S_other, *W_N_E) |
Intersect this with an other Bounds4Tuple. Arguments: `S_other` - Bottom `latS` (`scalar`) or an other Bounds4Tuple instance. `W_N_E` - Left `lonW`, top `latN` and right `lonE`, each a (`scalar`) for `scalar S_other`. Returns: `None` if the bounds do not overlap, otherwise the intersection of both as a Bounds4Tuple.